@@ -1,5 +1,3 @@
-# from sqlalchemy.ext.asyncio import AsyncSession as Session
-# from sqlalchemy.ext.asyncio import create_async_engine as _create_engine
 from sqlalchemy import (  # noqa: F401
     JSON,
     BigInteger,
@@ -16,10 +14,9 @@ from sqlalchemy import (  # noqa: F401
 )
 from sqlalchemy import create_engine as _create_engine
 from sqlalchemy import desc, func  # noqa: F401
+from sqlalchemy.exc import IntegrityError  # noqa: F401
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import (  # noqa: F401
-    Load,
-    Query,
     Session,
     declarative_mixin,
     joinedload,
@@ -33,27 +30,16 @@ from initcommerce.common.uuid import UUID
 
 logger = get_logger("initcommerce-utils")
 
-# HACK: enforce singleton
-_conn: Session = None
-
 
 def get_db(db_uri: str):
-    global _conn
+    engine = _create_engine(db_uri, pool_pre_ping=True)
 
-    # engine = _create_engine(db_uri, pool_pre_ping=True)
-    engine = _create_engine(db_uri)
-
-    if _conn is None:
-        SessionLocal = sessionmaker(
-            autocommit=False,
-            autoflush=False,
-            bind=engine,
-        )
-        _conn = SessionLocal()
-
-    if not _conn.is_active:
-        _conn.rollback()
-        logger.error("Connection rollback occurred!")
+    SessionLocal = sessionmaker(
+        autocommit=False,
+        autoflush=False,
+        bind=engine,
+    )
+    _conn = SessionLocal()
 
     return _conn
 
